# coding: utf-8

# flake8: noqa

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from sparkworks_client.api.command_api import CommandApi
from sparkworks_client.api.data_api import DataApi
from sparkworks_client.api.gateway_api import GatewayApi
from sparkworks_client.api.group_api import GroupApi
from sparkworks_client.api.participatory_sensing_api import ParticipatorySensingApi
from sparkworks_client.api.phenomenon_api import PhenomenonApi
from sparkworks_client.api.registry_api import RegistryApi
from sparkworks_client.api.resource_api import ResourceApi
from sparkworks_client.api.unit_api import UnitApi
from sparkworks_client.api.unit_conversion_api import UnitConversionApi

# import ApiClient
from sparkworks_client.api_client import ApiClient
from sparkworks_client.configuration import Configuration
# import models into sdk package
from sparkworks_client.models.a_participatory_sensing_resource_request_api_model import AParticipatorySensingResourceRequestAPIModel
from sparkworks_client.models.analytics_resource_data_response_dtoapi_model import AnalyticsResourceDataResponseDTOAPIModel
from sparkworks_client.models.command_api_model import CommandAPIModel
from sparkworks_client.models.gateway_create_dto import GatewayCreateDTO
from sparkworks_client.models.gateway_dto import GatewayDTO
from sparkworks_client.models.gateway_query_dto import GatewayQueryDTO
from sparkworks_client.models.group_create_dto import GroupCreateDTO
from sparkworks_client.models.group_dto import GroupDTO
from sparkworks_client.models.group_node_dto import GroupNodeDTO
from sparkworks_client.models.group_update_dto import GroupUpdateDTO
from sparkworks_client.models.phenomenon_create_dto import PhenomenonCreateDTO
from sparkworks_client.models.phenomenon_dto import PhenomenonDTO
from sparkworks_client.models.phenomenon_query_dto import PhenomenonQueryDTO
from sparkworks_client.models.phenomenon_update_dto import PhenomenonUpdateDTO
from sparkworks_client.models.publish_data_dtoapi_model import PublishDataDTOAPIModel
from sparkworks_client.models.publish_data_list_dtoapi_model import PublishDataListDTOAPIModel
from sparkworks_client.models.query_latest_resource_data_dtoapi_model import QueryLatestResourceDataDTOAPIModel
from sparkworks_client.models.query_latest_resource_data_result_dtoapi_model import QueryLatestResourceDataResultDTOAPIModel
from sparkworks_client.models.query_raw_data_time_range_dtoapi_model import QueryRawDataTimeRangeDTOAPIModel
from sparkworks_client.models.query_raw_data_time_range_result_dtoapi_model import QueryRawDataTimeRangeResultDTOAPIModel
from sparkworks_client.models.query_resource_data_criteria_dtoapi_model import QueryResourceDataCriteriaDTOAPIModel
from sparkworks_client.models.query_time_range_resource_data_criteria_dtoapi_model import QueryTimeRangeResourceDataCriteriaDTOAPIModel
from sparkworks_client.models.query_time_range_resource_data_dtoapi_model import QueryTimeRangeResourceDataDTOAPIModel
from sparkworks_client.models.query_time_range_resource_data_result_dtoapi_model import QueryTimeRangeResourceDataResultDTOAPIModel
from sparkworks_client.models.registry_pair_dto import RegistryPairDTO
from sparkworks_client.models.registry_record_dto import RegistryRecordDTO
from sparkworks_client.models.resource_create_dto import ResourceCreateDTO
from sparkworks_client.models.resource_dto import ResourceDTO
from sparkworks_client.models.resource_latest_values_response_api_model import ResourceLatestValuesResponseAPIModel
from sparkworks_client.models.resource_query_dto import ResourceQueryDTO
from sparkworks_client.models.resource_update_dto import ResourceUpdateDTO
from sparkworks_client.models.single_resource_measurement_api_model import SingleResourceMeasurementAPIModel
from sparkworks_client.models.the_resource_summary_data_api_model import TheResourceSummaryDataAPIModel
from sparkworks_client.models.unit_conversion_create_dto import UnitConversionCreateDTO
from sparkworks_client.models.unit_conversion_dto import UnitConversionDTO
from sparkworks_client.models.unit_conversion_query_dto import UnitConversionQueryDTO
from sparkworks_client.models.unit_create_dto import UnitCreateDTO
from sparkworks_client.models.unit_dto import UnitDTO
from sparkworks_client.models.unit_query_dto import UnitQueryDTO
from sparkworks_client.models.unit_update_dto import UnitUpdateDTO



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from sparkworks_client.models.single_resource_measurement_api_model import SingleResourceMeasurementAPIModel  # noqa: F401,E501


class QueryRawDataTimeRangeResultDTOAPIModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_from': 'int',
        'phenomenon_uuid': 'str',
        'resource_uuid': 'str',
        'results': 'list[SingleResourceMeasurementAPIModel]',
        'to': 'int',
        'unit_uuid': 'str'
    }

    attribute_map = {
        '_from': 'from',
        'phenomenon_uuid': 'phenomenonUuid',
        'resource_uuid': 'resourceUuid',
        'results': 'results',
        'to': 'to',
        'unit_uuid': 'unitUuid'
    }

    def __init__(self, _from=None, phenomenon_uuid=None, resource_uuid=None, results=None, to=None, unit_uuid=None):  # noqa: E501
        """QueryRawDataTimeRangeResultDTOAPIModel - a model defined in Swagger"""  # noqa: E501

        self.__from = None
        self._phenomenon_uuid = None
        self._resource_uuid = None
        self._results = None
        self._to = None
        self._unit_uuid = None
        self.discriminator = None

        self._from = _from
        if phenomenon_uuid is not None:
            self.phenomenon_uuid = phenomenon_uuid
        if resource_uuid is not None:
            self.resource_uuid = resource_uuid
        if results is not None:
            self.results = results
        self.to = to
        if unit_uuid is not None:
            self.unit_uuid = unit_uuid

    @property
    def _from(self):
        """Gets the _from of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501

        The UNIX timestamp of the start date for filtering  # noqa: E501

        :return: The _from of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501
        :rtype: int
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this QueryRawDataTimeRangeResultDTOAPIModel.

        The UNIX timestamp of the start date for filtering  # noqa: E501

        :param _from: The _from of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501
        :type: int
        """
        if _from is None:
            raise ValueError("Invalid value for `_from`, must not be `None`")  # noqa: E501

        self.__from = _from

    @property
    def phenomenon_uuid(self):
        """Gets the phenomenon_uuid of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501

        The Resource's Phenomenon UUID  # noqa: E501

        :return: The phenomenon_uuid of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._phenomenon_uuid

    @phenomenon_uuid.setter
    def phenomenon_uuid(self, phenomenon_uuid):
        """Sets the phenomenon_uuid of this QueryRawDataTimeRangeResultDTOAPIModel.

        The Resource's Phenomenon UUID  # noqa: E501

        :param phenomenon_uuid: The phenomenon_uuid of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501
        :type: str
        """

        self._phenomenon_uuid = phenomenon_uuid

    @property
    def resource_uuid(self):
        """Gets the resource_uuid of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501

        The UUID of the Resource  # noqa: E501

        :return: The resource_uuid of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._resource_uuid

    @resource_uuid.setter
    def resource_uuid(self, resource_uuid):
        """Sets the resource_uuid of this QueryRawDataTimeRangeResultDTOAPIModel.

        The UUID of the Resource  # noqa: E501

        :param resource_uuid: The resource_uuid of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501
        :type: str
        """

        self._resource_uuid = resource_uuid

    @property
    def results(self):
        """Gets the results of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501

        The requested raw data  # noqa: E501

        :return: The results of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501
        :rtype: list[SingleResourceMeasurementAPIModel]
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this QueryRawDataTimeRangeResultDTOAPIModel.

        The requested raw data  # noqa: E501

        :param results: The results of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501
        :type: list[SingleResourceMeasurementAPIModel]
        """

        self._results = results

    @property
    def to(self):
        """Gets the to of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501

        The UNIX timestamp of the end date for filtering  # noqa: E501

        :return: The to of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501
        :rtype: int
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this QueryRawDataTimeRangeResultDTOAPIModel.

        The UNIX timestamp of the end date for filtering  # noqa: E501

        :param to: The to of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501
        :type: int
        """
        if to is None:
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    @property
    def unit_uuid(self):
        """Gets the unit_uuid of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501

        The Resource's Unit UUID  # noqa: E501

        :return: The unit_uuid of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._unit_uuid

    @unit_uuid.setter
    def unit_uuid(self, unit_uuid):
        """Sets the unit_uuid of this QueryRawDataTimeRangeResultDTOAPIModel.

        The Resource's Unit UUID  # noqa: E501

        :param unit_uuid: The unit_uuid of this QueryRawDataTimeRangeResultDTOAPIModel.  # noqa: E501
        :type: str
        """

        self._unit_uuid = unit_uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(QueryRawDataTimeRangeResultDTOAPIModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryRawDataTimeRangeResultDTOAPIModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sparkworks_client.api_client import ApiClient


class DataApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_latest_by_uuid(self, uuid, **kwargs):  # noqa: E501
        """Retrieve latest values and analytics for a single Resource  # noqa: E501

        Retrieve the latest values received for a single Resource. The response contains the latest value received for the Resource, the timestamp of the measurement as well as the analytics calculated for this measurement for the last 5minute, hour, day and month interval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_latest_by_uuid(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The UUID of the Resource (required)
        :return: ResourceLatestValuesResponseAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_latest_by_uuid_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_latest_by_uuid_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def get_latest_by_uuid_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Retrieve latest values and analytics for a single Resource  # noqa: E501

        Retrieve the latest values received for a single Resource. The response contains the latest value received for the Resource, the timestamp of the measurement as well as the analytics calculated for this measurement for the last 5minute, hour, day and month interval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_latest_by_uuid_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The UUID of the Resource (required)
        :return: ResourceLatestValuesResponseAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_latest_by_uuid" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `get_latest_by_uuid`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/{uuid}/latest', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResourceLatestValuesResponseAPIModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_summary_by_uuid(self, uuid, **kwargs):  # noqa: E501
        """Retrieve the data summary for a single Resource  # noqa: E501

        Retrieve a summary of the latest analytics calculated for a single Resource. The summary contains the latest calculated analytics for the Resource for the past 48 5minute, hour, day and month intervals.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_summary_by_uuid(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The UUID of the Resource (required)
        :return: TheResourceSummaryDataAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_summary_by_uuid_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_summary_by_uuid_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def get_summary_by_uuid_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Retrieve the data summary for a single Resource  # noqa: E501

        Retrieve a summary of the latest analytics calculated for a single Resource. The summary contains the latest calculated analytics for the Resource for the past 48 5minute, hour, day and month intervals.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_summary_by_uuid_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The UUID of the Resource (required)
        :return: TheResourceSummaryDataAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_summary_by_uuid" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `get_summary_by_uuid`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/{uuid}/summary', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TheResourceSummaryDataAPIModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def publish_data(self, **kwargs):  # noqa: E501
        """Publish data to a single or multiple Resources  # noqa: E501

        Publish data to a single or multiple Resources. Send data for processing for one or more Resources that you have permission to update.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.publish_data(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PublishDataListDTOAPIModel publish_data_list_dto: Data to be published
        :return: PublishDataListDTOAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.publish_data_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.publish_data_with_http_info(**kwargs)  # noqa: E501
            return data

    def publish_data_with_http_info(self, **kwargs):  # noqa: E501
        """Publish data to a single or multiple Resources  # noqa: E501

        Publish data to a single or multiple Resources. Send data for processing for one or more Resources that you have permission to update.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.publish_data_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PublishDataListDTOAPIModel publish_data_list_dto: Data to be published
        :return: PublishDataListDTOAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['publish_data_list_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method publish_data" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'publish_data_list_dto' in params:
            body_params = params['publish_data_list_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/data/publish', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PublishDataListDTOAPIModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_latest(self, query_latest_resource_data_dto, **kwargs):  # noqa: E501
        """Retrieve the latest values received for multiple Resources  # noqa: E501

        Retrieve the latest values received for multiple Resources. The response contains the latest value received for the Resource and the timestamp of the measurement. For more information on how to define the criteria check the method parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_latest(query_latest_resource_data_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param QueryLatestResourceDataDTOAPIModel query_latest_resource_data_dto: Data query criteria (required)
        :return: QueryLatestResourceDataResultDTOAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_latest_with_http_info(query_latest_resource_data_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.query_latest_with_http_info(query_latest_resource_data_dto, **kwargs)  # noqa: E501
            return data

    def query_latest_with_http_info(self, query_latest_resource_data_dto, **kwargs):  # noqa: E501
        """Retrieve the latest values received for multiple Resources  # noqa: E501

        Retrieve the latest values received for multiple Resources. The response contains the latest value received for the Resource and the timestamp of the measurement. For more information on how to define the criteria check the method parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_latest_with_http_info(query_latest_resource_data_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param QueryLatestResourceDataDTOAPIModel query_latest_resource_data_dto: Data query criteria (required)
        :return: QueryLatestResourceDataResultDTOAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query_latest_resource_data_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_latest" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query_latest_resource_data_dto' is set
        if ('query_latest_resource_data_dto' not in params or
                params['query_latest_resource_data_dto'] is None):
            raise ValueError("Missing the required parameter `query_latest_resource_data_dto` when calling `query_latest`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_latest_resource_data_dto' in params:
            body_params = params['query_latest_resource_data_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/query/latest', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryLatestResourceDataResultDTOAPIModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_summary(self, query_resource_data_criteria_dto, **kwargs):  # noqa: E501
        """Retrieve the data summaries of mutliple Resource  # noqa: E501

        Retrieve the data summaries received of multiple Resources. The response contains the summary with calculated analytics for each Resource for the past 48 5minute, hour, day and month intervals. A single summary is returned for each Resource  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_summary(query_resource_data_criteria_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param QueryResourceDataCriteriaDTOAPIModel query_resource_data_criteria_dto: Data query criteria (required)
        :return: TheResourceSummaryDataAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_summary_with_http_info(query_resource_data_criteria_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.query_summary_with_http_info(query_resource_data_criteria_dto, **kwargs)  # noqa: E501
            return data

    def query_summary_with_http_info(self, query_resource_data_criteria_dto, **kwargs):  # noqa: E501
        """Retrieve the data summaries of mutliple Resource  # noqa: E501

        Retrieve the data summaries received of multiple Resources. The response contains the summary with calculated analytics for each Resource for the past 48 5minute, hour, day and month intervals. A single summary is returned for each Resource  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_summary_with_http_info(query_resource_data_criteria_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param QueryResourceDataCriteriaDTOAPIModel query_resource_data_criteria_dto: Data query criteria (required)
        :return: TheResourceSummaryDataAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query_resource_data_criteria_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_summary" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query_resource_data_criteria_dto' is set
        if ('query_resource_data_criteria_dto' not in params or
                params['query_resource_data_criteria_dto'] is None):
            raise ValueError("Missing the required parameter `query_resource_data_criteria_dto` when calling `query_summary`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_resource_data_criteria_dto' in params:
            body_params = params['query_resource_data_criteria_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/query/summary', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TheResourceSummaryDataAPIModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_time_range(self, query_time_range_resource_data_dto, **kwargs):  # noqa: E501
        """Retrieve analytics for a single Resource  # noqa: E501

        Retrieve analytics for a single Resource on multiple intervals and granularities. The response contains the latest calculated analytics for the Resource based on the query criteria provided with the request. For more information on how to define the criteria check the method parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_time_range(query_time_range_resource_data_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param QueryTimeRangeResourceDataDTOAPIModel query_time_range_resource_data_dto: Timerange criteria (required)
        :return: QueryTimeRangeResourceDataResultDTOAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_time_range_with_http_info(query_time_range_resource_data_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.query_time_range_with_http_info(query_time_range_resource_data_dto, **kwargs)  # noqa: E501
            return data

    def query_time_range_with_http_info(self, query_time_range_resource_data_dto, **kwargs):  # noqa: E501
        """Retrieve analytics for a single Resource  # noqa: E501

        Retrieve analytics for a single Resource on multiple intervals and granularities. The response contains the latest calculated analytics for the Resource based on the query criteria provided with the request. For more information on how to define the criteria check the method parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_time_range_with_http_info(query_time_range_resource_data_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param QueryTimeRangeResourceDataDTOAPIModel query_time_range_resource_data_dto: Timerange criteria (required)
        :return: QueryTimeRangeResourceDataResultDTOAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query_time_range_resource_data_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_time_range" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query_time_range_resource_data_dto' is set
        if ('query_time_range_resource_data_dto' not in params or
                params['query_time_range_resource_data_dto'] is None):
            raise ValueError("Missing the required parameter `query_time_range_resource_data_dto` when calling `query_time_range`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_time_range_resource_data_dto' in params:
            body_params = params['query_time_range_resource_data_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/query/timerange', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryTimeRangeResourceDataResultDTOAPIModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_time_range_raw(self, query_raw_data_time_range_dto, **kwargs):  # noqa: E501
        """Retrieve the raw data received for a single Resource  # noqa: E501

        Retrieve the raw data received for a single Resource over a specified time interval. This method retrieves from the raw data storage and depending on the amount of data that need to be accessed may take longer time to respond. If your get a response timeout you may need to limit the requested time range.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_time_range_raw(query_raw_data_time_range_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param QueryRawDataTimeRangeDTOAPIModel query_raw_data_time_range_dto: Raw Data Timerange Criteria (required)
        :return: QueryRawDataTimeRangeResultDTOAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_time_range_raw_with_http_info(query_raw_data_time_range_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.query_time_range_raw_with_http_info(query_raw_data_time_range_dto, **kwargs)  # noqa: E501
            return data

    def query_time_range_raw_with_http_info(self, query_raw_data_time_range_dto, **kwargs):  # noqa: E501
        """Retrieve the raw data received for a single Resource  # noqa: E501

        Retrieve the raw data received for a single Resource over a specified time interval. This method retrieves from the raw data storage and depending on the amount of data that need to be accessed may take longer time to respond. If your get a response timeout you may need to limit the requested time range.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_time_range_raw_with_http_info(query_raw_data_time_range_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param QueryRawDataTimeRangeDTOAPIModel query_raw_data_time_range_dto: Raw Data Timerange Criteria (required)
        :return: QueryRawDataTimeRangeResultDTOAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query_raw_data_time_range_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_time_range_raw" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query_raw_data_time_range_dto' is set
        if ('query_raw_data_time_range_dto' not in params or
                params['query_raw_data_time_range_dto'] is None):
            raise ValueError("Missing the required parameter `query_raw_data_time_range_dto` when calling `query_time_range_raw`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_raw_data_time_range_dto' in params:
            body_params = params['query_raw_data_time_range_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/query/raw/timerange', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryRawDataTimeRangeResultDTOAPIModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.data_api import DataApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestDataApi(unittest.TestCase):
    """DataApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.data_api.DataApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_latest_by_uuid(self):
        """Test case for get_latest_by_uuid

        Retrieve latest values and analytics for a single Resource  # noqa: E501
        """
        pass

    def test_get_summary_by_uuid(self):
        """Test case for get_summary_by_uuid

        Retrieve the data summary for a single Resource  # noqa: E501
        """
        pass

    def test_publish_data(self):
        """Test case for publish_data

        Publish data to a single or multiple Resources  # noqa: E501
        """
        pass

    def test_query_latest(self):
        """Test case for query_latest

        Retrieve the latest values received for multiple Resources  # noqa: E501
        """
        pass

    def test_query_summary(self):
        """Test case for query_summary

        Retrieve the data summaries of mutliple Resource  # noqa: E501
        """
        pass

    def test_query_time_range(self):
        """Test case for query_time_range

        Retrieve analytics for a single Resource  # noqa: E501
        """
        pass

    def test_query_time_range_raw(self):
        """Test case for query_time_range_raw

        Retrieve the raw data received for a single Resource  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from sparkworks_client.api.command_api import CommandApi
from sparkworks_client.api.data_api import DataApi
from sparkworks_client.api.gateway_api import GatewayApi
from sparkworks_client.api.group_api import GroupApi
from sparkworks_client.api.participatory_sensing_api import ParticipatorySensingApi
from sparkworks_client.api.phenomenon_api import PhenomenonApi
from sparkworks_client.api.registry_api import RegistryApi
from sparkworks_client.api.resource_api import ResourceApi
from sparkworks_client.api.unit_api import UnitApi
from sparkworks_client.api.unit_conversion_api import UnitConversionApi
